package com.duanledexianxianxian.demo;

import io.minio.BucketExistsArgs;
import io.minio.MakeBucketArgs;
import io.minio.MinioClient;
import io.minio.PutObjectArgs;
import io.minio.errors.MinioException;

import java.io.IOException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;

/**
 * @author duanledexianxianxian
 * @date 2021/3/2 1:25
 * @since 1.0.0
 */
public class MinIOClientDemo {
    public static void main(String[] args) {
        try {
            // 使用MinIO服务的URL，端口，Access key和Secret key创建一个MinioClient对象
            MinioClient minioClient =
                    MinioClient.builder()
                            .endpoint("http://platform.kuopu.net:50001")
                            .credentials("minio", "minio123")
                            .build();

            // 检查存储桶是否已经存在
            boolean isExist = minioClient.bucketExists(BucketExistsArgs.builder().bucket("kim-dev").build());
            if (isExist) {
                System.out.println("Bucket already exists.");
            } else {
                // 创建一个名为kim-dev的存储桶，用于存储照片的zip文件。
                minioClient.makeBucket(MakeBucketArgs.builder().bucket("kim-dev").build());
            }

            // 使用putObject上传一个文件到存储桶中。
            minioClient.putObject(PutObjectArgs.builder().bucket("kim-dev").object("data2.txt").stream(
                    MinIOClientDemo.class.getClassLoader().getResourceAsStream("./files/data2.txt"), -1, 1024*5*1024)
                    .contentType("video/mp4")
                    .build());
            System.out.println("this.getClass().getClassLoader().getResource(\"/files/data2.txt\") is successfully uploaded as asiaphotos.zip to `asiatrip` bucket.");
        } catch (MinioException e) {
            System.out.println("Error occurred: " + e);
        } catch (NoSuchAlgorithmException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } catch (InvalidKeyException e) {
            e.printStackTrace();
        }
        //// 当前类的目录
        //System.out.println(MinIOClientDemo.class.getResource(""));
        //// 当前项目的目录
        //System.out.println(MinIOClientDemo.class.getResource("/"));
        //// 当前类的目录下的文件
        //System.out.println(MinIOClientDemo.class.getResource("data1.txt"));
        //// 绝对路径不存在
        //System.out.println(MinIOClientDemo.class.getResource("/data1.txt"));
        //
        //// 当前项目的目录
        //System.out.println(MinIOClientDemo.class.getClassLoader().getResource(""));
        //System.out.println(MinIOClientDemo.class.getClassLoader().getResource("/"));
        //System.out.println(MinIOClientDemo.class.getClassLoader().getResource("data1.txt"));
        //System.out.println(MinIOClientDemo.class.getClassLoader().getResource("/data1.txt"));
        //// 当前项目的目录
        //System.out.println(MinIOClientDemo.class.getClassLoader().getResource("application.yml"));
        //// 当前项目的目录
        //System.out.println(MinIOClientDemo.class.getClassLoader().getResource("./files/data2.txt"));
    }

}
